@@ -85,7 +85,7 @@ def main(defaults_file=None, specific_outfile=None):
     start = BASE
     if BASE_ON_SERVER:
         output = commands.getoutput("svn list %s" % BASE_ON_SERVER)
-        if not 'not under version control' in output:
+        if not 'Unable' in output:
             start = BASE_ON_SERVER
     startpoint = lister.SvnLister(start, ignore=BLACKLIST)
     info_extracter = extracter.BaseExtracter
